#ifdef STUPID_KDE_AUTOMAKE

#include "effects.h"
#include "effects.moc"
#include "playlistsaver.h"
#include "playlistsaver.moc"
#include "playlist.h"
#include "playlist.moc"
#include "plugin.h"
#include "plugin.moc"
#include "video.h"
#include "video.moc"
#include "controls.h"
#include "controls.moc"
#include "engine.h"
#include "engine.moc"
#include "pref.h"
#include "pref.moc"
#include "equalizer.h"
#include "equalizer.moc"
#include "stdaction.h"
#include "stdaction.moc"
#include "scrollinglabel.h"
#include "scrollinglabel.moc"
#include "downloader.h"
#include "downloader.moc"
#include "app.h"
#include "app.moc"
#include "player.h"
#include "player.moc"
#include "stereobuttonaction.h"
#include "stereobuttonaction.moc"
#include "vequalizer.h"
#include "vequalizer.moc"

#endif

